@@ -92,7 +92,6 @@ correlation <- function(df,
     ci <- corr$ci
     ci.adj <- corr$ci.adj
 
-    r <- psych::corr.test(df, y = df2, use = "pairwise", method = method)$r
   } else {
     if (is.null(df2) == FALSE) {
       df <- cbind(df, df2)
@@ -143,7 +142,7 @@ correlation <- function(df,
   if (is.null(p) == FALSE) {
     if (adjust != "none") {
       if ((type == "full" & is.null(df2) == FALSE) | (type == "semi")) {
-        p <- p.adjust(p, method = adjust)
+        p[,] <- p.adjust(p, method = adjust)
       } else {
         p[lower.tri(p)] <- p.adjust(p[lower.tri(p)], method = adjust, n = choose(nrow(p), 2))
         p[upper.tri(p)] <- p.adjust(p[upper.tri(p)], method = adjust, n = choose(nrow(p), 2))
